<?php

// U.S. Department of Labor
// Bureau Of Labor Statistics 
// Quarterly Census of Employment and Wages
// June 2016
// 
// QCEW Open Data Access for PHP 5.4
//  
// This version was written using PHP 5.4 and should work with other 
// versions. However, some modification may be needed. 
//
// Submit questions at: http://www.bls.gov/cgi-bin/forms/cew?/cew/home.htm
//
// *******************************************************************************


// *******************************************************************************
// qcewCreateDataRows : This function fetches a CSV file at the provided URL then
// builds and returns a two-dimensional array containing the data and the header 
// row of the csv file

function qcewMakeDataTable($csvUrl) {
    $dataTable = array();
    $file = fopen($csvUrl,"r");
    while(! feof($file)) {
        array_push($dataTable,fgetcsv($file));
    }
    fclose($file);
    return $dataTable;
}

// *******************************************************************************




// *******************************************************************************
// qcewGetAreaData : This function takes a year, quarter, and area argument and
// returns an array containing the associated area data. Use 'a' for annual
// averages. 
// For all area codes and titles see:
// http://data.bls.gov/cew/doc/titles/area/area_titles.htm
function qcewGetAreaData($year,$qtr,$area) {
    $url = "http://data.bls.gov/cew/data/api/";
    $url .= $year . "/" . $qtr . "/area/" . $area . ".csv";
    return qcewMakeDataTable($url);
}

// *******************************************************************************




// *******************************************************************************
// qcewGetIndustryData : This function takes a year, quarter, and industry code
// and returns an array containing the associated industry data. Use 'a' for 
// annual averages. Some industry codes contain hyphens. the CSV files use
// underscores instead of hyphens. So 31-33 becomes 31_33. 
// For all industry codes and titles see:
// http://data.bls.gov/cew/doc/titles/industry/industry_titles.htm

function qcewGetIndustryData($year,$qtr,$industry) {
    $url = "http://data.bls.gov/cew/data/api/";
    $url .= $year . "/" . $qtr . "/industry/" . $industry . ".csv";
    return qcewMakeDataTable($url);
}

// *******************************************************************************




// *******************************************************************************
// qcewGetSizeData : This function takes a year and establishment size class code
// and returns an array containing the associated size data. Size data
// is only available for the first quarter of each year.
// For all establishment size classes and titles see:
// http://data.bls.gov/cew/doc/titles/size/size_titles.htm

function qcewGetSizeData($year,$size) {
    $url = "http://data.bls.gov/cew/data/api/";
    $url .= $year . "/" . $qtr . "/size/" . $size . ".csv";
    return qcewMakeDataTable($url);
}

// *******************************************************************************




$Michigan = qcewGetAreaData("2015","1","26000");

// print the First Record's establishment count.
// note that row 0 (zero) is contains the csv file's headers.
echo $Michigan[1][8];


?>
